@@ -84,9 +84,8 @@ def video_dl(url):
                 f.write(data)
                 data = video.read(CHUNK_SIZE)
                 
-                sys.stdout.write(" "*40 + "\r")
-                sys.stdout.write("  %s/%s MB – %0.2f %%\r" % (format_mb(size), format_mb(target_size), round((float(size) / target_size)*100, 2)))
-                sys.stdout.flush()
+                print(" "*40, end="\r")
+                print("%s/%s MB – %0.2f %%" % (format_mb(size), format_mb(target_size), round((float(size) / target_size)*100, 2)), end="\r")
     
         print()
         return True
